==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/OutlierDetectionFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import com.fasterxml.jackson.databind.JsonSerializer;
import java.lang.String;
import com.fasterxml.jackson.databind.JsonDeserializer;
import java.lang.Deprecated;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.SerializerProvider;
import java.lang.Boolean;
import java.lang.Override;
import com.fasterxml.jackson.core.JsonParser;
import me.snowdrop.istio.api.DurationFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import me.snowdrop.istio.api.Duration;
import java.lang.Integer;
import javax.validation.Valid;
import java.lang.Long;
import me.snowdrop.istio.api.DurationBuilder;

public interface OutlierDetectionFluent<A extends OutlierDetectionFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBaseEjectionTime instead.
 * @return The buildable object.
 */
@Deprecated public Duration getBaseEjectionTime();
    public Duration buildBaseEjectionTime();
    public A withBaseEjectionTime(Duration baseEjectionTime);
    public Boolean hasBaseEjectionTime();
    public A withNewBaseEjectionTime(Integer nanos,Long seconds);
    public OutlierDetectionFluent.BaseEjectionTimeNested<A> withNewBaseEjectionTime();
    public OutlierDetectionFluent.BaseEjectionTimeNested<A> withNewBaseEjectionTimeLike(Duration item);
    public OutlierDetectionFluent.BaseEjectionTimeNested<A> editBaseEjectionTime();
    public OutlierDetectionFluent.BaseEjectionTimeNested<A> editOrNewBaseEjectionTime();
    public OutlierDetectionFluent.BaseEjectionTimeNested<A> editOrNewBaseEjectionTimeLike(Duration item);
    public Integer getConsecutiveErrors();
    public A withConsecutiveErrors(Integer consecutiveErrors);
    public Boolean hasConsecutiveErrors();
    public A withNewConsecutiveErrors(String arg1);
    public A withNewConsecutiveErrors(int arg1);
    
/**
 * This method has been deprecated, please use method buildInterval instead.
 * @return The buildable object.
 */
@Deprecated public Duration getInterval();
    public Duration buildInterval();
    public A withInterval(Duration interval);
    public Boolean hasInterval();
    public A withNewInterval(Integer nanos,Long seconds);
    public OutlierDetectionFluent.IntervalNested<A> withNewInterval();
    public OutlierDetectionFluent.IntervalNested<A> withNewIntervalLike(Duration item);
    public OutlierDetectionFluent.IntervalNested<A> editInterval();
    public OutlierDetectionFluent.IntervalNested<A> editOrNewInterval();
    public OutlierDetectionFluent.IntervalNested<A> editOrNewIntervalLike(Duration item);
    public Integer getMaxEjectionPercent();
    public A withMaxEjectionPercent(Integer maxEjectionPercent);
    public Boolean hasMaxEjectionPercent();
    public A withNewMaxEjectionPercent(String arg1);
    public A withNewMaxEjectionPercent(int arg1);

    public interface BaseEjectionTimeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DurationFluent<OutlierDetectionFluent.BaseEjectionTimeNested<N>>{

        
    public N and();    public N endBaseEjectionTime();
}
    public interface IntervalNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DurationFluent<OutlierDetectionFluent.IntervalNested<N>>{

        
    public N and();    public N endInterval();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/OutlierDetectionFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import me.snowdrop.istio.api.DurationFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import me.snowdrop.istio.api.Duration;
import com.fasterxml.jackson.databind.JsonSerializer;
import com.fasterxml.jackson.databind.JsonDeserializer;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.SerializerProvider;
import java.lang.Boolean;
import java.lang.Override;
import com.fasterxml.jackson.core.JsonParser;
import me.snowdrop.istio.api.DurationBuilder;

public interface OutlierDetectionFluent<A extends OutlierDetectionFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBaseEjectionTime instead.
 * @return The buildable object.
 */
@Deprecated public Duration getBaseEjectionTime();
    public Duration buildBaseEjectionTime();
    public A withBaseEjectionTime(Duration baseEjectionTime);
    public Boolean hasBaseEjectionTime();
    public A withNewBaseEjectionTime(Integer nanos,Long seconds);
    public OutlierDetectionFluent.BaseEjectionTimeNested<A> withNewBaseEjectionTime();
    public OutlierDetectionFluent.BaseEjectionTimeNested<A> withNewBaseEjectionTimeLike(Duration item);
    public OutlierDetectionFluent.BaseEjectionTimeNested<A> editBaseEjectionTime();
    public OutlierDetectionFluent.BaseEjectionTimeNested<A> editOrNewBaseEjectionTime();
    public OutlierDetectionFluent.BaseEjectionTimeNested<A> editOrNewBaseEjectionTimeLike(Duration item);
    public Integer getConsecutiveErrors();
    public A withConsecutiveErrors(Integer consecutiveErrors);
    public Boolean hasConsecutiveErrors();
    
/**
 * This method has been deprecated, please use method buildInterval instead.
 * @return The buildable object.
 */
@Deprecated public Duration getInterval();
    public Duration buildInterval();
    public A withInterval(Duration interval);
    public Boolean hasInterval();
    public A withNewInterval(Integer nanos,Long seconds);
    public OutlierDetectionFluent.IntervalNested<A> withNewInterval();
    public OutlierDetectionFluent.IntervalNested<A> withNewIntervalLike(Duration item);
    public OutlierDetectionFluent.IntervalNested<A> editInterval();
    public OutlierDetectionFluent.IntervalNested<A> editOrNewInterval();
    public OutlierDetectionFluent.IntervalNested<A> editOrNewIntervalLike(Duration item);
    public Integer getMaxEjectionPercent();
    public A withMaxEjectionPercent(Integer maxEjectionPercent);
    public Boolean hasMaxEjectionPercent();
    public Integer getMinHealthPercent();
    public A withMinHealthPercent(Integer minHealthPercent);
    public Boolean hasMinHealthPercent();

    public interface BaseEjectionTimeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DurationFluent<OutlierDetectionFluent.BaseEjectionTimeNested<N>>{

        
    public N and();    public N endBaseEjectionTime();
}
    public interface IntervalNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DurationFluent<OutlierDetectionFluent.IntervalNested<N>>{

        
    public N and();    public N endInterval();
}


}
